# Core Developers #

----------
- Sepand Haghighi - Sharif University Of Technology - ([@sepandhaghighi](http://github.com/sepandhaghighi)) ([sepand@pyrgg.ir](mailto:sepand@pyrgg.ir))
- Sadra Sabouri - Sharif University Of Technology - ([@sadrasabouri](https://github.com/sadrasabouri)) ([sadra@pyrgg.ir](mailto:sadra@pyrgg.ir))

# Other Contributors #
----------
- [ivanovmg](https://github.com/ivanovmg)

